#################################################################
#
#   Sketchup to Marathon Converter - Texture Import
#
#   This script takes a set of wall textures exported as
#   image files and loads them into a Sketchup model, suitably
#   named for use by the Marathon Export script.
#
#   The image files should be in a folder called Walls1,
#   Walls2, etc. depending on the texture set they came from.
#
#   The textures are set up to be mirrored, so that they appear
#   the right way around when applied to the back of a face,
#   as they will be most of the time.
#
#################################################################

class MarathonTextureImporter

	def abort(mess)
		UI.beep()
		UI.messagebox(mess)
		throw :Abort
	end
	
	def get_texture_directory()
		model = Sketchup.active_model
		dir = File.dirname(model.path)
		path = UI.openpanel("Find one of the files in the texture set to be imported:",
			dir, "")
		texture_dir = File.dirname(path)
		#printf("Texture dir = %s\n", texture_dir) ###
		return texture_dir
	end
	
	def texture_set_number(texture_dir)
		set_name = File.basename(texture_dir)
		#printf("Set name = %s\n", set_name) ###
		if set_name[0, 5] != "Walls"
			abort("Directory must be named Walls<n> where <n> is the texture set number.")
		end
		n = set_name.sub("Walls", "").to_i()
		printf("Wall set number = %s\n", n)
		if n < 1 or n > 5
			abort("Texture set number must be between 1 and 5.")
		end
		set_number = 17 + (n - 1)
		#printf("Texture set number = %s\n", set_number) ###
		return set_number
	end
	
	def add_textures(set_number, pathnames)
		materials = Sketchup.active_model.materials
		for i in 0...pathnames.length
			path = pathnames[i]
			name = format("%d-%d", set_number, i)
			mat = materials[name]
			if not mat
				#printf("Creating material %s\n", name) ###
				mat = materials.add(name)
			end
			#printf("Setting %s to %s\n", name, path) ###
			mat.texture = path
			tex = mat.texture
			tex.size = [-1, 1]
			printf("Texture %s size = %s, %s\n", mat.name, tex.width, tex.height) ###
		end
	end

	def run()
		catch :Abort do
			texture_dir = get_texture_directory()
			set_number = texture_set_number(texture_dir)
			pattern = File.join(texture_dir, "*.*")
			pathnames = Dir.glob(pattern)
			pathnames.sort!()
			#printf("%s\n", pathnames.inspect) ###
			add_textures(set_number, pathnames)
		end
	end

end # class MarathonTextureImporter

module Marathon

	def Marathon.import_textures()
		MarathonTextureImporter.new().run()
	end

end # module Marathon

if (not $Marathon_ImportTextures)
	menu = marathon_submenu()
	menu.add_separator()
	menu.add_item("Import Textures") {Marathon.import_textures()}
	$Marathon_ImportTextures = true
end
